==> haskell-options-1.2.1.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: options
version: 1.2.1.1
id: options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
key: options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
stability: stable
homepage: https://john-millikin.com/software/haskell-options/
synopsis: A powerful and easy-to-use command-line option parser.
description:
    The @options@ package lets library and application developers easily work
    with command-line options.
    .
    The following example is a full program that can accept two options,
    @--message@ and @--quiet@:
    .
    @
    import Control.Applicative
    import Options
    .
    data MainOptions = MainOptions
    &#x20;   &#x7b; optMessage :: String
    &#x20;   , optQuiet :: Bool
    &#x20;   &#x7d;
    .
    instance '\''Options'\'' MainOptions where
    &#x20;   defineOptions = pure MainOptions
    &#x20;       \<*\> simpleOption \"message\" \"Hello world!\"
    &#x20;           \"A message to show the user.\"
    &#x20;       \<*\> simpleOption \"quiet\" False
    &#x20;           \"Whether to be quiet.\"
    .
    main :: IO ()
    main = runCommand $ \\opts args -> do
    &#x20;   if optQuiet opts
    &#x20;       then return ()
    &#x20;       else putStrLn (optMessage opts)
    @
    .
    >$ ./hello
    >Hello world!
    >$ ./hello --message='\''ciao mondo'\''
    >ciao mondo
    >$ ./hello --quiet
    >$
    .
    In addition, this library will automatically create documentation options
    such as @--help@ and @--help-all@:
    .
    >$ ./hello --help
    >Help Options:
    >  -h, --help
    >    Show option summary.
    >  --help-all
    >    Show all help options.
    >
    >Application Options:
    >  --message :: text
    >    A message to show the user.
    >    default: "Hello world!"
    >  --quiet :: bool
    >    Whether to be quiet.
    >    default: false
category: Console
abi: 82f7e41db0b6dfc72d432d74abd3aea7
exposed: True
exposed-modules:
    Options
hidden-modules: Options.Help Options.Tokenize Options.Types
                Options.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/options-1.2.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/options-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/options-1.2.1.1
hs-libraries: HSoptions-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
depends:
    base-4.11.1.0 containers-0.5.11.0
    monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU=4c03848dd0a896fa90647e3d99c076d1
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-options/html/options.haddock
haddock-html: /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-options-1.2.1.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: options
version: 1.2.1.1
id: options-1.2.1.1-H1XEWS9AsRzLWmt2uccJIp
key: options-1.2.1.1-H1XEWS9AsRzLWmt2uccJIp
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
stability: stable
homepage: https://john-millikin.com/software/haskell-options/
synopsis: A powerful and easy-to-use command-line option parser.
description:
    The @options@ package lets library and application developers easily work
    with command-line options.
    .
    The following example is a full program that can accept two options,
    @--message@ and @--quiet@:
    .
    @
    import Control.Applicative
    import Options
    .
    data MainOptions = MainOptions
    &#x20;   &#x7b; optMessage :: String
    &#x20;   , optQuiet :: Bool
    &#x20;   &#x7d;
    .
    instance '\''Options'\'' MainOptions where
    &#x20;   defineOptions = pure MainOptions
    &#x20;       \<*\> simpleOption \"message\" \"Hello world!\"
    &#x20;           \"A message to show the user.\"
    &#x20;       \<*\> simpleOption \"quiet\" False
    &#x20;           \"Whether to be quiet.\"
    .
    main :: IO ()
    main = runCommand $ \\opts args -> do
    &#x20;   if optQuiet opts
    &#x20;       then return ()
    &#x20;       else putStrLn (optMessage opts)
    @
    .
    >$ ./hello
    >Hello world!
    >$ ./hello --message='\''ciao mondo'\''
    >ciao mondo
    >$ ./hello --quiet
    >$
    .
    In addition, this library will automatically create documentation options
    such as @--help@ and @--help-all@:
    .
    >$ ./hello --help
    >Help Options:
    >  -h, --help
    >    Show option summary.
    >  --help-all
    >    Show all help options.
    >
    >Application Options:
    >  --message :: text
    >    A message to show the user.
    >    default: "Hello world!"
    >  --quiet :: bool
    >    Whether to be quiet.
    >    default: false
category: Console
abi: f9cdc2c08e3392dfa2916dfe85251694
exposed: True
exposed-modules:
    Options
hidden-modules: Options.Help Options.Tokenize Options.Types
                Options.Util
import-dirs: /usr/lib/ghc-8.6.1/site-local/options-1.2.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/options-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/options-1.2.1.1
hs-libraries: HSoptions-1.2.1.1-H1XEWS9AsRzLWmt2uccJIp
depends:
    base-4.12.0.0 containers-0.6.0.1
    monads-tf-0.1.0.3-DFJmu4IXpHk2UzhiB94rsJ transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-options/html/options.haddock
haddock-html: /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
